Module: ActiveRecord::Bitwise

Defined in:
lib/active_record/bitwise.rb,
lib/active_record/bitwise/version.rb

Overview

The main namespace for the ActiveRecord::Bitwise gem, which provides capabilities to store multiple boolean or enum values in a single integer column.

Defined Under Namespace

Modules: Model, RelationExtension, WhereChainExtension Classes: Error, NotSupportedError, Type

Constant Summary collapse

VERSION =

The current version of the activerecord-bitwise gem.

'0.10.0'